@@ -4,7 +4,7 @@ use Carp;
 use DBI;
 use strict;
 use Class::ReturnValue;
-use vars qw($VERSION @ISA $DBIHandle $DEBUG $TRANSDEPTH);
+use vars qw($VERSION @ISA %DBIHandle $DEBUG $TRANSDEPTH);
 
 $TRANSDEPTH = 0;
 
@@ -288,9 +288,9 @@ sub dbh {
   my $self=shift;
   
   #If we are setting the database handle, set it.
-  $DBIHandle = shift if (@_);
+  $DBIHandle{$self} = shift if (@_);
 
-  return($DBIHandle);
+  return($DBIHandle{$self});
 }
 
 # }}}
@@ -529,8 +529,6 @@ sub DatabaseVersion {
 
 # {{{ CaseSensitive
 
-
-
 =head2 CaseSensitive
 
 Returns 1 if the current database's searches are case sensitive by default
@@ -546,6 +544,33 @@ sub CaseSensitive {
 
 # }}} 
 
+
+# {{{ _MakeClauseCaseInsensitive
+
+=head2 _MakeClauseCaseInsensitive FIELD OPERATOR VALUE
+
+Takes a field, operator and value. performs the magic necessary to make
+your database treat this clause as case insensitive.
+
+Returns a FIELD OPERATOR VALUE triple.
+
+=cut
+
+sub _MakeClauseCaseInsensitive {
+    my $self = shift;
+    my $field = shift;
+    my $operator = shift;
+    my $value = shift;
+
+    $field = "lower($field)";
+    $value = lc($value);
+
+    return ($field, $operator, $value);
+}
+
+
+# }}}
+
 # {{{ BeginTransaction
 
 =head2 BeginTransaction
@@ -760,6 +785,7 @@ When we get rid of the Searchbuilder::Handle, we need to disconnect from the dat
 sub DESTROY {
   my $self = shift;
   $self->Disconnect if $self->{'DisconnectHandleOnDestroy'};
+  delete $DBIHandle{$self};
 }
 
 
